<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el_GR">
<context>
    <name>RCadToolBar</name>
    <message>
        <location filename="../src/gui/RCadToolBar.cpp" line="+139"/>
        <source>Vertical/Horizontal</source>
        <translation>Κατακόρυφο/Οριζόντιο</translation>
    </message>
</context>
<context>
    <name>RCadToolBarPanel</name>
    <message>
        <location filename="../src/gui/RCadToolBarPanel.cpp" line="+23"/>
        <location line="+63"/>
        <source>Back</source>
        <translation>Πίσω</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+154"/>
        <source>Custom</source>
        <translation>Προσαρμοσμένο</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+211"/>
        <source>Grid</source>
        <translation>Πλέγμα</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>Άκρο</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>Σε οντότητα</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>Κάθετο</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation>Εφαπτόμενο</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>Κέντρο</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>Μέσο</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>Τομή</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>Αναφορά</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Distance</source>
        <translation>Απόσταση</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+188"/>
        <source>Invalid</source>
        <translation>Μη έγκυρο</translation>
    </message>
</context>
</TS>
